OC.L10N.register(
    "deck",
    {
    "The file was uploaded" : "Ulac afaylu yettwaznen",
    "The file was only partially uploaded" : "Afaylu, cwiṭ kan i yettwaznen segs",
    "No file was uploaded" : "Ulac afaylu i d-yettwasulin",
    "Missing a temporary folder" : "Ixuṣ ukaram akudan",
    "Finished" : "Immed",
    "Done" : "Immed",
    "Attachments" : "Ticeqqufin",
    "File" : "Afaylu",
    "Cancel" : "Sefsex",
    "Open" : "Ldi",
    "Completed" : "Yemmed",
    "Details" : "Talqayt",
    "Sharing" : "Beṭṭu",
    "Tags" : "Tibzimin",
    "Activity" : "Armud",
    "Owner" : "Bab",
    "Delete" : "Kkes",
    "Edit" : "Ẓreg",
    "Download" : "Sider",
    "Modified" : "Yettwabeddel",
    "Created" : "Yettwarna.",
    "Comments" : "Commentaires",
    "Save" : "Sekles",
    "Cancel reply" : "Semmet tiririt.",
    "Reply" : "Err",
    "Search" : "Nadi",
    "Cancel edit" : "Sefsex aseẓreg",
    "No notifications" : "Ulac tisezmal",
    "Today" : "Ass-a",
    "Close" : "Mdel",
    "Share" : "Bḍu",
    "Personal" : "Udmawan"
},
"nplurals=2; plural=(n != 1);");
